/**
 * Copyright Universidad de Valladolid 2024
 */
package es.markse;

/**
 * Implementacion de la clase abstracta TrayectoSimple
 * @author javcalv
 * @author victorm
 */
public abstract class Simple extends Trayecto {
	
    protected double distanciaKilometros;
    private final float MILLAS_A_KILOMETROS = 1.852f;
    
    /**
     * Constructor del TrayectoSimple
     * @param muelleOrigen Muelle desde el que empieza el Trayecto
	 * @param puertoOrigen Puerto desde el que empieza el Trayecto
	 * @param fechaInicioTrayecto Fecha en la que comienza el Trayecto
	 * @param muelleDestino Muelle en el que finaliza un Trayecto
	 * @param puertoDestino Puerto en el que finaliza un Trayecto
	 * @param fechaFinTrayecto Fecha en la que finaliza un Trayecto
     */
    public Simple(Muelle muelleOrigen, Puerto puertoOrigen, Fecha fechaInicioTrayecto, Muelle muelleDestino, Puerto puertoDestino, Fecha fechaFinTrayecto) {
        super(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
        
        if (!comprobacionMuellesDistintos(muelleOrigen, muelleDestino, puertoOrigen, puertoDestino))
			throw new IllegalArgumentException("El muelle de origen no puede ser igual al de destino");
        
      //Obtenemos la distancia en millas marinas del trayecto y las convertimos en kilometros
        this.distanciaKilometros = convertirMillasAKilometros(distanciaMillasMarinas());
        
    }
    
    /**
	 * Método que Comprueba si los Muelles Introducidos son Distintos o no
	 * @param muelleOrigen Muelle desde el que comienza el Trayecto
	 * @param muelleDestino Muelle en el que finaliza el Trayecto
	 * @return true si los muelles son distintos o false si son los mismos
	 */
	private boolean comprobacionMuellesDistintos(Muelle muelleOrigen, Muelle muelleDestino, Puerto puertoOrigen, Puerto puertoDestino) {
		return (muelleOrigen.getIdentificador() == muelleDestino.getIdentificador() && 
				puertoOrigen.identificadorPuerto().equals(puertoDestino.identificadorPuerto())) ? false : true;	
	}
    
	/******************
	 * METODOS SIMPLE *
	 ******************/
	
    /**
     * Metodo que sirve para convertir las Millas marinas a Kilometros
     * @param millas Millas de un trayecto
     * @return Kilometros de un trayecto
     */
    private double convertirMillasAKilometros(double millas) {
        return millas * this.MILLAS_A_KILOMETROS;
    }
}

