/**
 * Copyright Universidad de Valladolid 2024
 */
package es.markse;

/**
 * Implementacion de la clase TBarco, que representa un trayecto por barco.
 * @author javcalv
 * @author victorm
 */
public class TBarco extends Simple {
	
    private final double COSTE_DIARIO = 4000;

    /**
     * Constructor de la clase TBarco
     * @param muelleOrigen Muelle desde el que empieza el Trayecto
     * @param puertoOrigen Puerto desde el que empieza el Trayecto
     * @param fechaInicioTrayecto Fecha en la que comienza el Trayecto
     * @param muelleDestino Muelle en el que finaliza un Trayecto
     * @param puertoDestino Puerto en el que finaliza un Trayecto
     * @param fechaFinTrayecto Fecha en la que finaliza un Trayecto
     * @throws IllegalStateException el Muelle de origen esta alejado del barco
     * @throws IllegalStateException el Muelle de destino esta alejado del barco
     */
    public TBarco(Muelle muelleOrigen, Puerto puertoOrigen, Fecha fechaInicioTrayecto, Muelle muelleDestino, Puerto puertoDestino, Fecha fechaFinTrayecto) {
        super(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
        
        //Comprobamos si el Muelle origen/destino esta alejado del barco
        if(muelleOrigen.alejadoBarco())
        	throw new IllegalStateException("El Muelle de origen esta alejado del barco (No puede usar este transporte)");
        if(muelleDestino.alejadoBarco())
        	throw new IllegalStateException("El Muelle de destino esta alejado del barco (No puede usar ese transporte)");
    }

    /**
     * Método que calcula el coste del trayecto por barco
     * @return Coste del trayecto en euros
     */
    @Override
    public double costeTrayecto() {
        int dias = numeroDeDiasDeTrayecto();
        return dias * COSTE_DIARIO;
    }
}