/**
 * Copyright Universidad de Valladolid 2024
 */
package es.markse;

/**
 * Implementacion de la clase TTren, que representa un trayecto por tren.
 * @author javcalv
 * @author victorm
 */
public class TTren extends TVehiculoTierra{
	
    private double COSTE = 20;
    private double COSTE_KILOMETRO = 12.5;

    /**
     * Constructor de la clase TTren
     * @param muelleOrigen Muelle desde el que empieza el Trayecto
     * @param puertoOrigen Puerto desde el que empieza el Trayecto
     * @param fechaInicioTrayecto Fecha en la que comienza el Trayecto
     * @param muelleDestino Muelle en el que finaliza un Trayecto
     * @param puertoDestino Puerto en el que finaliza un Trayecto
     * @param fechaFinTrayecto Fecha en la que finaliza un Trayecto
     * @throws IllegalStateException si el muelle de origen no puede usar el tren
     * @throws IllegalStateException si el muelle de destino no puede usar el tren
     */
    public TTren(Muelle muelleOrigen, Puerto puertoOrigen, Fecha fechaInicioTrayecto, Muelle muelleDestino, Puerto puertoDestino, Fecha fechaFinTrayecto) {
        super(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
        
        //Comprobamos si los muelles de origen y destino pueden usar el tren
        if(!muelleOrigen.utilidadTren())
        	throw new IllegalStateException("El muelle de origen no puede usar el transporte Tren");
        if(!muelleDestino.utilidadTren())
        	throw new IllegalStateException("El muelle destino no puede usar el transporte Tren");  
        
        //Inicializamos los valores para el trayecto Tren
        this.COSTE_FIJO = COSTE;
        this.COSTE_POR_KILOMETRO = this.COSTE_KILOMETRO;
    }
}