package es.markse;

import static org.junit.Assert.*;
import java.util.ArrayList;
import org.junit.Test;
import es.markse.Muelle.estado;
import es.uva.inf.poo.maps.GPSCoordinate;

public class CombinadoTest{

	@Test
	public void testCombinado() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		ArrayList<Simple> trayectosSimples = new ArrayList<>();
		Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoConexion = new Puerto("IT", "NAP");
		puertoConexion.anyadirMuelle(muelleConexion);
		Fecha fechaConexion = new Fecha(25,10,2015);
		TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
		TTren tb = new TTren(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
		trayectosSimples.add(tc);
		trayectosSimples.add(tb);
		new PackCamionTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
	}
	
	@Test(expected=IllegalArgumentException.class)
	public void testEstanVacios() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		ArrayList<Simple> trayectosSimples = new ArrayList<>();
		Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoConexion = new Puerto("IT", "NAP");
		puertoConexion.anyadirMuelle(muelleConexion);
		new PackCamionTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
	}

	@Test(expected = IllegalArgumentException.class)
	public void testComprobarTrayectoBarco() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		ArrayList<Simple> trayectosSimples = new ArrayList<>();
		Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoConexion = new Puerto("IT", "NAP");
		puertoConexion.anyadirMuelle(muelleConexion);
		Fecha fechaConexion = new Fecha(25,10,2015);
		TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
		TBarco tb = new TBarco(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
		trayectosSimples.add(tc);
		trayectosSimples.add(tb);
		new PackCamionTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
	}	
	
		@Test(expected = IllegalArgumentException.class)
		public void testComprobarSiHayTrayectosCamion() {
			Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
			Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
			Puerto puertoOrigen = new Puerto("ES", "BAR");
			Puerto puertoDestino = new Puerto("ES", "VAL");
			puertoOrigen.anyadirMuelle(muelleOrigen);
			puertoDestino.anyadirMuelle(muelleDestino);
			Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
			Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
			ArrayList<Simple> trayectosSimples = new ArrayList<>();
			Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
			Puerto puertoConexion = new Puerto("IT", "NAP");
			puertoConexion.anyadirMuelle(muelleConexion);
			Fecha fechaConexion = new Fecha(25,10,2015);
			TTren tc = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
			TTren tt = new TTren(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
			trayectosSimples.add(tc);
			trayectosSimples.add(tt);
			new PackCamionTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
		}

	
	
		@Test(expected = IllegalArgumentException.class)
		public void testComprobarSiHayTrayectosTren() {
			Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
			Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
			Puerto puertoOrigen = new Puerto("ES", "BAR");
			Puerto puertoDestino = new Puerto("ES", "VAL");
			puertoOrigen.anyadirMuelle(muelleOrigen);
			puertoDestino.anyadirMuelle(muelleDestino);
			Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
			Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
			ArrayList<Simple> trayectosSimples = new ArrayList<>();
			Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
			Puerto puertoConexion = new Puerto("IT", "NAP");
			puertoConexion.anyadirMuelle(muelleConexion);
			Fecha fechaConexion = new Fecha(25,10,2015);
			TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
			TCamion tt = new TCamion(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
			trayectosSimples.add(tc);
			trayectosSimples.add(tt);
			new PackCamionTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
		}

		@Test
		public void testCosteTrayecto() {
			Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
			Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
			Puerto puertoOrigen = new Puerto("ES", "BAR");
			Puerto puertoDestino = new Puerto("ES", "VAL");
			puertoOrigen.anyadirMuelle(muelleOrigen);
			puertoDestino.anyadirMuelle(muelleDestino);
			Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
			Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
			ArrayList<Simple> trayectosSimples = new ArrayList<>();
			Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
			Puerto puertoConexion = new Puerto("IT", "NAP");
			puertoConexion.anyadirMuelle(muelleConexion);
			Fecha fechaConexion = new Fecha(25,10,2015);
			TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
			TTren tb = new TTren(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
			trayectosSimples.add(tc);
			trayectosSimples.add(tb);
			PackCamionTren pct = new PackCamionTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
			assertEquals(pct.precioTrayectoEnEuros(), 71138.12, 0.01f);
		}
		
		@Test (expected = IllegalArgumentException.class)
		public void testPackCamionTrenOrdenTrayectosInvalido() {
			Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
			Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
			Puerto puertoOrigen = new Puerto("ES", "BAR");
			Puerto puertoDestino = new Puerto("ES", "VAL");
			puertoOrigen.anyadirMuelle(muelleOrigen);
			puertoDestino.anyadirMuelle(muelleDestino);
			Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
			Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
			ArrayList<Simple> trayectosSimples = new ArrayList<>();
			Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
			Puerto puertoConexion = new Puerto("IT", "NAP");
			puertoConexion.anyadirMuelle(muelleConexion);
			Fecha fechaConexion = new Fecha(25,10,2015);
			TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
			TTren tb = new TTren(muelleDestino,puertoDestino, fechaConexion, muelleConexion, puertoConexion, fechaFinTrayecto);
			trayectosSimples.add(tc);
			trayectosSimples.add(tb);
			new PackCamionTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
		}
		
		@Test (expected = IllegalArgumentException.class)
		public void testPackCamionTrayectosOrigenInvalidos() {
			Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
			Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
			Puerto puertoOrigen = new Puerto("ES", "BAR");
			Puerto puertoDestino = new Puerto("ES", "VAL");
			puertoOrigen.anyadirMuelle(muelleOrigen);
			puertoDestino.anyadirMuelle(muelleDestino);
			Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
			Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
			ArrayList<Simple> trayectosSimples = new ArrayList<>();
			Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
			Puerto puertoConexion = new Puerto("IT", "NAP");
			puertoConexion.anyadirMuelle(muelleConexion);
			Fecha fechaConexion = new Fecha(25,10,2015);
			TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
			TTren tt = new TTren(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
			trayectosSimples.add(tc);
			trayectosSimples.add(tt);
			new PackCamionTren(muelleDestino, puertoDestino, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
		}
		
		@Test (expected = IllegalArgumentException.class)
		public void testPackCamionTrayectosDestinoInvalidos() {
			Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
			Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
			Puerto puertoOrigen = new Puerto("ES", "BAR");
			Puerto puertoDestino = new Puerto("ES", "VAL");
			puertoOrigen.anyadirMuelle(muelleOrigen);
			puertoDestino.anyadirMuelle(muelleDestino);
			Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
			Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
			ArrayList<Simple> trayectosSimples = new ArrayList<>();
			Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
			Puerto puertoConexion = new Puerto("IT", "NAP");
			puertoConexion.anyadirMuelle(muelleConexion);
			Fecha fechaConexion = new Fecha(25,10,2015);
			TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
			TTren tt = new TTren(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
			trayectosSimples.add(tc);
			trayectosSimples.add(tt);
			new PackCamionTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleOrigen, puertoOrigen, fechaInicioTrayecto, trayectosSimples);
		}
		
		
		
}