package es.markse;

import static org.junit.Assert.*;

import java.util.ArrayList;

import org.junit.Test;
import es.markse.Contenedor.*;
import es.markse.Muelle.estado;
import es.uva.inf.poo.maps.GPSCoordinate;

public class ContenedorTest {
	
	@Test (expected = IllegalArgumentException.class)
	public final void testContenedorPesoTaraInvalida() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		new Estandar(iso, 0, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS, true);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testContenedorMaximaCargaInvalida() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		new Estandar(iso, 200, 0, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS, true);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testContenedorVolumenInvalida() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		new Estandar(iso, 200, 500, 0, estados.REGOGIDA, pesos.KILOS, volumenes.METROS, true);
	}
	
	@Test
	public final void testContenedorEstandar() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Estandar e = new Estandar(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS, true);
		assertTrue(e.tieneTecho());
	}
	
	@Test
	public final void testContenedorEstandarAlternarTecho() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Estandar e = new Estandar(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS, true);
		assertTrue(e.tieneTecho());
		e.alternarTecho();
		assertFalse(e.tieneTecho());
		e.alternarTecho();
		assertTrue(e.tieneTecho());
	}
	
	@Test
	public final void testContenedorEstandarAgregarTrayecto() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Estandar e = new Estandar(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS, true);
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		TBarco tb = new TBarco(muelleDestino,puertoDestino, fechaFinTrayecto,muelleOrigen,puertoOrigen, fechaFinTrayecto);
		e.anyadirTrayecto(tt);
		e.anyadirTrayecto(tb);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testContenedorEstandarAgregarTrayectoNulo() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Estandar e = new Estandar(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS, true);
		e.anyadirTrayecto(null);
	}
	
	@Test
	public final void testContenedorRefrigerado() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Refrigerado r = new Refrigerado(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		assertTrue(r.tieneTecho());
	}
	
	@Test
	public final void testContenedorRefrigeradoAgregarTrayecto() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Refrigerado r = new Refrigerado(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TBarco tb = new TBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		TBarco tb2 = new TBarco(muelleDestino, puertoDestino, fechaFinTrayecto, muelleOrigen, puertoOrigen, fechaFinTrayecto);
		r.anyadirTrayecto(tb);
		r.anyadirTrayecto(tb2);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testContenedorRefrigeradoAgregarTrayectoNulo() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Refrigerado r = new Refrigerado(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		r.anyadirTrayecto(null);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testContenedorRefrigeradoAgregarTrayectoTren() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Refrigerado r = new Refrigerado(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tb = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		r.anyadirTrayecto(tb);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testContenedorRefrigeradoAgregarTrayectoPackCamionTren() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Refrigerado r = new Refrigerado(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		ArrayList<Simple> trayectosSimples = new ArrayList<>();
		Muelle muelleConexion = new Muelle("03", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoConexion = new Puerto("IT", "NAP");
		puertoConexion.anyadirMuelle(muelleConexion);
		Fecha fechaConexion = new Fecha(25,10,2015);
		TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
		TTren tt = new TTren(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
		trayectosSimples.add(tc);
		trayectosSimples.add(tt);
		PackCamionTren pct = new PackCamionTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
		r.anyadirTrayecto(pct);
	}
	
	@Test
	public final void testContenedorFlatRack() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		FlatRack fr = new FlatRack(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		assertFalse(fr.tieneTecho());
	}
	
	@Test
	public final void testContenedorFlatRackAgregartrayecto() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		FlatRack fr = new FlatRack(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		TBarco tb = new TBarco(muelleDestino,puertoDestino, fechaFinTrayecto,muelleOrigen,puertoOrigen, fechaFinTrayecto);
		fr.anyadirTrayecto(tt);
		fr.anyadirTrayecto(tb);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testContenedorFlatRackAgregartrayectoNulo() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		FlatRack fr = new FlatRack(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		fr.anyadirTrayecto(null);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testContenedorFlatRackAgregartrayectoCamion() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		FlatRack fr = new FlatRack(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		fr.anyadirTrayecto(tc);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testContenedorFlatRackAgregartrayectoPackCamionTren() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		FlatRack fr = new FlatRack(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		TTren tt = new TTren(muelleDestino, puertoDestino, fechaFinTrayecto, muelleOrigen, puertoOrigen, fechaFinTrayecto);
		ArrayList<Simple> ts = new ArrayList<>();
		ts.add(tc);
		ts.add(tt);
		PackCamionTren pct = new PackCamionTren(muelleOrigen,puertoOrigen,fechaInicioTrayecto,muelleOrigen,puertoOrigen,fechaFinTrayecto,ts);
		fr.anyadirTrayecto(pct);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testContenedorFlatRackAgregartrayectoPackCamionBarco() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		FlatRack fr = new FlatRack(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		TBarco tb = new TBarco(muelleDestino, puertoDestino, fechaFinTrayecto, muelleOrigen, puertoOrigen, fechaFinTrayecto);
		ArrayList<Simple> ts = new ArrayList<>();
		ts.add(tc);
		ts.add(tb);
		PackCamionBarco pcb = new PackCamionBarco(muelleOrigen,puertoOrigen,fechaInicioTrayecto,muelleOrigen,puertoOrigen,fechaFinTrayecto,ts);
		fr.anyadirTrayecto(pcb);
	}
	
	
	@Test
	public final void testCambiarEstadoARecogida() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Estandar e = new Estandar(iso, 200, 500, 1000, estados.TRANSITO, pesos.KILOS, volumenes.METROS, true);
		assertFalse(e.contenedorEnRecogida());
		e.cambiarEstadoARecogida();
		assertTrue(e.contenedorEnRecogida());
	}

	@Test
	public final void testCambiarEstadoATransito() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Estandar e = new Estandar(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS, true);
		assertFalse(e.contenedorEnTransito());
		e.cambiarEstadoATransito();
		assertTrue(e.contenedorEnTransito());
	}

	@Test
	public final void testVolumenEnMetrosCubicos() {
		ISO6346 i = new ISO6346("ZRE", 'J', 56731);
		Contenedor c = new Estandar(i, 100, 400, 500, estados.TRANSITO, pesos.KILOS, volumenes.METROS, false);
		assertEquals(500f, c.volumenEnMetrosCubicos(), 0.01f);
		ISO6346 i2 = new ISO6346("DRT", 'U', 56731);
		Contenedor c2 = new Estandar(i2, 100, 400, 500, estados.TRANSITO, pesos.KILOS, volumenes.PIES, false);
		assertEquals(500 * 0.0283168f, c2.volumenEnMetrosCubicos(), 0.01f);
	}

	@Test
	public final void testVolumenEnPiesCubicos() {
		ISO6346 i = new ISO6346("ZRE", 'J', 56731);
		Contenedor c = new Estandar(i, 100, 400, 500, estados.TRANSITO, pesos.KILOS, volumenes.METROS, false);
		assertEquals(500f * 35.3147f, c.volumenEnPiesCubicos(), 0.01f);
		ISO6346 i2 = new ISO6346("DRT", 'U', 56731);
		Contenedor c2 = new Estandar(i2, 100, 400, 500, estados.TRANSITO, pesos.KILOS, volumenes.PIES, false);
		assertEquals(500f, c2.volumenEnPiesCubicos(), 0.001f);
	}

	@Test
	public final void testObtenerPesoKilos() {
		ISO6346 i = new ISO6346("ZRE", 'J', 56731);
		Contenedor c = new Estandar(i, 100, 400, 500, estados.TRANSITO, pesos.KILOS, volumenes.METROS, false);
		assertEquals(100f, c.obtenerPesoKilos(), 0.01f);
		ISO6346 i2 = new ISO6346("DFT", 'J', 589012);
		Contenedor c2 = new Estandar(i2, 100, 400, 500, estados.TRANSITO, pesos.LIBRAS, volumenes.METROS, false);
		assertEquals(100f *0.453592, c2.obtenerPesoKilos(), 0.01f);
	}

	@Test
	public final void testObtenerPesoLibras() {
		ISO6346 i = new ISO6346("ZRE", 'J', 56731);
		Contenedor c = new Estandar(i, 100, 400, 500, estados.TRANSITO, pesos.LIBRAS, volumenes.METROS, false);
		assertEquals(100f, c.obtenerPesoLibras(), 0.01f);
		ISO6346 i2 = new ISO6346("DRT", 'U', 56731);
		Contenedor c2 = new Estandar(i2, 100, 400, 500, estados.TRANSITO, pesos.KILOS, volumenes.PIES, false);
		assertEquals(100f * 2.20462, c2.obtenerPesoLibras(), 0.01f);

	}

	@Test
	public final void testPrecioTransporteTotalContenedor() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Refrigerado r = new Refrigerado(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TBarco tb = new TBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		TBarco tb2 = new TBarco(muelleDestino, puertoDestino, fechaFinTrayecto, muelleOrigen, puertoOrigen, fechaFinTrayecto);
		r.anyadirTrayecto(tb);
		r.anyadirTrayecto(tb2);
		assertEquals(r.precioTransporteTotalContenedor(), 48000.0, 0.01f);
	}
	
	@Test
	public final void testPrecioTransporteTotalContenedorSinTrayectos() {
		ISO6346 iso = new ISO6346("ZTE", 'J', 458971);
		Refrigerado r = new Refrigerado(iso, 200, 500, 1000, estados.REGOGIDA, pesos.KILOS, volumenes.METROS);
		assertEquals(r.precioTransporteTotalContenedor(), 0.0, 0.01f);
	}


	@Test
	public final void testCargaUtilContenedorKilos() {
		ISO6346 i = new ISO6346("ZRE", 'J', 56731);
		Contenedor c = new Estandar(i, 100, 400, 500, estados.TRANSITO, pesos.KILOS, volumenes.METROS, false);
		assertEquals(400f, c.cargaUtilContenedorKilos(), 0.01f);
		ISO6346 i2 = new ISO6346("DRT", 'U', 56731);
		Contenedor c2 = new Estandar(i2, 100, 400, 500, estados.TRANSITO, pesos.LIBRAS, volumenes.PIES, false);
		assertEquals(400f *0.453592, c2.cargaUtilContenedorKilos(), 0.01f);

	}

	@Test
	public final void testCargaUtilContenedorLibras() {
		ISO6346 i = new ISO6346("ZRE", 'J', 56731);
		Contenedor c = new Estandar(i, 100, 400, 500, estados.TRANSITO, pesos.LIBRAS, volumenes.METROS, false);
		assertEquals(400f, c.cargaUtilContenedorLibras(), 0.01f);
		ISO6346 i2 = new ISO6346("DRT", 'U', 56731);
		Contenedor c2 = new Estandar(i2, 100, 400, 500, estados.TRANSITO, pesos.KILOS, volumenes.PIES, false);
		assertEquals(400f * 2.20462, c2.cargaUtilContenedorLibras(), 0.01f);

	}

	@Test
	public final void testGetCodigo() {
		ISO6346 i = new ISO6346("ZRE", 'J', 56731);
		Contenedor c = new Estandar(i, 100, 400, 500, estados.TRANSITO, pesos.LIBRAS, volumenes.METROS, false);
		assertEquals(c.getCodigo(), "ZREJ0567310");
	}
	
	@Test (expected = IllegalStateException.class)
	public final void testanyadirTrayectoFechaInicioAnteriorAUltimoTrayecto() {
		ISO6346 i = new ISO6346("ZRE", 'J', 56731);
		Estandar e = new Estandar(i, 100, 400, 500, estados.TRANSITO, pesos.LIBRAS, volumenes.METROS, false);
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		TBarco tb = new TBarco(muelleDestino,puertoDestino, fechaInicioTrayecto,muelleOrigen,puertoOrigen, fechaFinTrayecto);
		e.anyadirTrayecto(tt);
		e.anyadirTrayecto(tb);
	}
	
	@Test (expected = IllegalStateException.class)
	public final void testanyadirTrayectoPuertoDestinoYOrigenDistintos() {
		ISO6346 i = new ISO6346("ZRE", 'J', 56731);
		Estandar e = new Estandar(i, 100, 400, 500, estados.TRANSITO, pesos.LIBRAS, volumenes.METROS, false);
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		TBarco tb = new TBarco(muelleOrigen,puertoOrigen, fechaFinTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		e.anyadirTrayecto(tt);
		e.anyadirTrayecto(tb);
	}
	
	@Test (expected = IllegalStateException.class)
	public final void testanyadirTrayectoFechaMuelleOrigenDestinoDistintos() {
		ISO6346 i = new ISO6346("ZRE", 'J', 56731);
		Estandar e = new Estandar(i, 100, 400, 500, estados.TRANSITO, pesos.LIBRAS, volumenes.METROS, false);
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		Muelle m2 = new Muelle("05", new GPSCoordinate(12.0, -9.5), estado.OPERATIVO, 10, 3, true, false);
		puertoDestino.anyadirMuelle(m2);
		TBarco tb = new TBarco(m2, puertoDestino, fechaFinTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		e.anyadirTrayecto(tt);
		e.anyadirTrayecto(tb);
	}
	
	@Test
	public final void testTieneTecho() {
		ISO6346 i = new ISO6346("ZRE", 'J', 56731);
		Estandar e = new Estandar(i, 100, 400, 500, estados.TRANSITO, pesos.LIBRAS, volumenes.METROS, false);
		assertFalse(e.tieneTecho());
	}
}
