/**
 * Copyright Universidad de Valladolid 2024/2025
 */
package es.markse;

import static org.junit.Assert.*;
import org.junit.Test;

/**
 * Test para la clase ISO6346
 * @author javcalv
 * @author victorm
 */
public class ISO6346Test {

	@Test
	public final void testISO6346() {
		ISO6346 codigo = new ISO6346("RTX", 'J', 893);
		assertEquals("RTX", codigo.codigoDuenyo());
		assertEquals('J', codigo.equipamiento());
		assertEquals(893, codigo.numeroSerie());
		assertEquals("RTXJ0008931", codigo.codigoContenedor());
	}
	
	@Test
	public final void testISO6346EquipamientoZ() {
		ISO6346 codigo = new ISO6346("RTX", 'Z', 893);
		assertEquals('Z', codigo.equipamiento());
	}
	
	@Test
	public final void testISO6346EquipamientoU() {
		ISO6346 codigo = new ISO6346("RTX", 'U', 893);
		assertEquals('U', codigo.equipamiento());
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testISO6346CodigoNulo() {
		new ISO6346(null, 'J', 893);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testISO6346CodigoInvalido() {
		new ISO6346("r4", 'J', 893);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testISO6346EquipamientoInvalido() {
		new ISO6346("RTX", '4', 893);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testISO6346NumeroSerieMenor() {
		new ISO6346("RTX", 'J', -405);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testISO6346NumeroSerieMayor() {
		new ISO6346("RTX", 'J', 56789012);
	}

	@Test(expected=IllegalArgumentException.class)
	public void testEquipamientoIncorrecto() {
		new ISO6346("RTX", 'W', 405);
	}

}
