/**
 *Copyright UVa 2024 
 */
package es.markse;

import static org.junit.Assert.*;

import java.util.ArrayList;

import org.junit.Test;
import es.uva.inf.poo.maps.GPSCoordinate;
import es.markse.Muelle.estado;

/**
 * Implementacion de los test para PackCamionBarco
 * @author javcalv
 * @author victorm
 */
public class PackCamionBarcoTest {

	@Test
	public void testPackCamionBarco() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		ArrayList<Simple> trayectosSimples = new ArrayList<>();
		Muelle muelleConexion = new Muelle("03", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoConexion = new Puerto("IT", "NAP");
		puertoConexion.anyadirMuelle(muelleConexion);
		Fecha fechaConexion = new Fecha(25,10,2015);
		TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
		TBarco tb = new TBarco(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
		trayectosSimples.add(tc);
		trayectosSimples.add(tb);
		PackCamionBarco pcb = new PackCamionBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
		assertEquals(pcb.getMuelleOrigen().getIdentificador(), "01");
		assertEquals(pcb.getPuertoDestino().identificadorPuerto(), "ES-VAL");
	}
	
	@Test (expected = IllegalArgumentException.class)
	public void testPackCamionBarcoTrayectosNulos() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		ArrayList<Simple> trayectosSimples = new ArrayList<>();
		new PackCamionBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
	}
	
	
	@Test (expected = IllegalArgumentException.class)
	public void testPackCamionBarcoTrayectosIncorrectos() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		ArrayList<Simple> trayectosSimples = new ArrayList<>();
		Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoConexion = new Puerto("IT", "NAP");
		puertoConexion.anyadirMuelle(muelleConexion);
		Fecha fechaConexion = new Fecha(25,10,2015);
		TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
		TTren tb = new TTren(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
		trayectosSimples.add(tc);
		trayectosSimples.add(tb);
		new PackCamionBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
	}
	

	
	@Test (expected = IllegalArgumentException.class)
	public void testPackCamionBarcosSinTrayectosCamion() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		ArrayList<Simple> trayectosSimples = new ArrayList<>();
		Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoConexion = new Puerto("IT", "NAP");
		puertoConexion.anyadirMuelle(muelleConexion);
		Fecha fechaConexion = new Fecha(25,10,2015);
		TBarco tc = new TBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
		TBarco tb = new TBarco(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
		trayectosSimples.add(tc);
		trayectosSimples.add(tb);
		new PackCamionBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public void testPackCamionBarcoSinTrayectosBarco() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		ArrayList<Simple> trayectosSimples = new ArrayList<>();
		Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoConexion = new Puerto("IT", "NAP");
		puertoConexion.anyadirMuelle(muelleConexion);
		Fecha fechaConexion = new Fecha(25,10,2015);
		TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
		TCamion tb = new TCamion(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
		trayectosSimples.add(tc);
		trayectosSimples.add(tb);
		new PackCamionBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public void testPackCamionBarcoOrdenTrayectosIncorrecto() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		ArrayList<Simple> trayectosSimples = new ArrayList<>();
		Muelle muelleConexion = new Muelle("01", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoConexion = new Puerto("IT", "NAP");
		puertoConexion.anyadirMuelle(muelleConexion);
		Fecha fechaConexion = new Fecha(25,10,2015);
		TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
		TBarco tb = new TBarco(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
		trayectosSimples.add(tb);
		trayectosSimples.add(tc);
		new PackCamionBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
	}

	@Test
	public void testCosteTrayecto() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		ArrayList<Simple> trayectosSimples = new ArrayList<>();
		Muelle muelleConexion = new Muelle("03", new GPSCoordinate(10.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoConexion = new Puerto("IT", "NAP");
		puertoConexion.anyadirMuelle(muelleConexion);
		Fecha fechaConexion = new Fecha(25,10,2015);
		TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleConexion, puertoConexion, fechaConexion);
		TBarco tb = new TBarco(muelleConexion,puertoConexion, fechaConexion, muelleDestino, puertoDestino, fechaFinTrayecto);
		trayectosSimples.add(tc);
		trayectosSimples.add(tb);
		PackCamionBarco pcb = new PackCamionBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto, trayectosSimples);
		assertEquals(pcb.costeTrayecto(), 48002.33, 0.01f);
	}
}