/**
 * Copyright UVa 2024/2025
 */
package es.markse;

import static org.junit.Assert.*;

import org.junit.Test;

import es.markse.Muelle.estado;
import es.uva.inf.poo.maps.GPSCoordinate;

/**
 * Implementcaion de los test para la clase Simple
 * @author javcalv
 * @author victorm
 *
 */
public class SimpleTest {

	@Test
	public void testSimple() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TBarco tb = new TBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertFalse(tb.getMuelleOrigen().alejadoBarco());
		assertEquals(tb.getPuertoDestino().identificadorPuerto(), "ES-VAL");
	}
	
	@Test (expected = IllegalArgumentException.class)
	public void testSimpleMuellesYPuertosIguales() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("01",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "BAR");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
	}
	
	@Test (expected = IllegalStateException.class)
	public void testTBarcoMuelleOrigenAlejadoBarco() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, true);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);	
	}
	
	@Test (expected = IllegalStateException.class)
	public void testTBarcoMuelleDestinoAlejadoBarco() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, true);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);	
	}
	
	@Test
	public void testTBarcoCosteTrayecto() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TBarco tb = new TBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertEquals(tb.costeTrayecto(),44000, 0.01f);
	}
	
	@Test
	public void testTTren() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertEquals(tt.getMuelleDestino().getIdentificador(), "02");
	}
	
	@Test (expected = IllegalStateException.class)
	public void testTTrenMuelleOrigenUtilidadTrenFalsa() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, false, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
	}
	
	@Test (expected = IllegalStateException.class)
	public void testTTrenMuelleDestinoUtilidadTrenFalsa() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, false, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
	}
	
	@Test
	public void testTCamion() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, false, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TCamion tc = new TCamion(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertEquals(tc.getMuelleOrigen().getIdentificador(), "01");
	}
}