/**
 * 
 */
package es.markse;

import static org.junit.Assert.*;
import org.junit.Test;
import es.markse.Muelle.estado;
import es.uva.inf.poo.maps.GPSCoordinate;

/**
 * Implementacion de los test para la clase abstracta Traycto
 * @author javcalv
 * @author victorm
 *
 */
public class TrayectoTest {

	@Test
	public final void testTrayecto() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertEquals(tt.getMuelleOrigen().getIdentificador(), "01");
		assertTrue(tt.getMuelleDestino().estaOperativo());
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testTrayectoMuelleOrigenNulo() {
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TTren(null, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testTrayectoMuelleDestinoNulo() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TBarco(muelleOrigen, puertoOrigen, fechaInicioTrayecto, null, puertoDestino, fechaFinTrayecto);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testTrayectoPuertoOrigenNulo() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TTren(muelleOrigen, null, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
	}

	@Test (expected = IllegalArgumentException.class)
	public final void testTrayectoPuertoDestinoNulo() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, null, fechaFinTrayecto);
		
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testTrayectoFechaInicioNula() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TTren(muelleOrigen, puertoOrigen, null, muelleDestino, puertoDestino, fechaFinTrayecto);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testTrayectoFechaFinNula() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, null);
	}
	
	@Test (expected = IllegalStateException.class)
	public final void testTrayectoMuelleOrigenFueraServicio() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.FUERA_DE_SERVICIO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
	}
	
	@Test (expected = IllegalStateException.class)
	public final void testTrayectoMuelleDestinoFueraServicio() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.FUERA_DE_SERVICIO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
	}
	
	@Test (expected = IllegalStateException.class)
	public final void testTrayectoMuelleOrigenNoPerteneceAPuerto() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
	}
	
	@Test (expected = IllegalStateException.class)
	public final void testTrayectoMuelleDestinoNoPerteneceAPuerto() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testTrayectoFechaFinAnteriorAFechaInicio() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		new TTren(muelleOrigen, puertoOrigen, fechaFinTrayecto, muelleDestino, puertoDestino, fechaInicioTrayecto);
	}

	
	@Test
	public final void testFechaFinTrayectoSuperior() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		boolean b = tt.FechaFinTrayectoSuperior(new Fecha(25,10,2015));
		boolean b2 = tt.FechaFinTrayectoSuperior(new Fecha(10,11,2015));
		assertFalse(b);
		assertTrue(b2);
	}
	
	@Test (expected = IllegalArgumentException.class)
	public final void testFechaFinTrayectoSuperiorNulo() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		tt.FechaFinTrayectoSuperior(null);
	}

	
	@Test
	public final void testPrecioTrayectoEnEuros() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertEquals(tt.precioTrayectoEnEuros(), 76520.91, 0.01f);
	}

	@Test
	public final void testInforTrayecto() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		String s = tt.inforTrayecto();
		assertEquals(s, tt.inforTrayecto());
	}

	@Test
	public final void testNumeroDeDiasDeTrayecto() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertEquals(tt.numeroDeDiasDeTrayecto(), 11);
	}

	@Test
	public final void testGetMuelleOrigen() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertEquals(tt.getMuelleOrigen(), muelleOrigen);
	}

	@Test
	public final void testGetMuelleDestino() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertEquals(tt.getMuelleDestino(), muelleDestino);
	}

	@Test
	public final void testGetPuertoOrigen() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertEquals(tt.getPuertoOrigen(), puertoOrigen);
	}

	@Test
	public final void testGetPuertoDestino() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertEquals(tt.getPuertoDestino(), puertoDestino);
	}

	@Test
	public final void testGetFechaInicioTrayecto() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertEquals(tt.getFechaInicioTrayecto(), fechaInicioTrayecto);
	}

	@Test
	public final void testGetFechaFinTrayecto() {
		Muelle muelleOrigen = new Muelle("01", new GPSCoordinate(10.0, 15.0), estado.OPERATIVO, 10, 3, true, false);
		Muelle muelleDestino = new Muelle("02",  new GPSCoordinate(15.0, -15.0), estado.OPERATIVO, 10, 3, true, false);
		Puerto puertoOrigen = new Puerto("ES", "BAR");
		Puerto puertoDestino = new Puerto("ES", "VAL");
		puertoOrigen.anyadirMuelle(muelleOrigen);
		puertoDestino.anyadirMuelle(muelleDestino);
		Fecha fechaInicioTrayecto = new Fecha(20, 10, 2015);
		Fecha fechaFinTrayecto = new Fecha(30, 10, 2015);
		TTren tt = new TTren(muelleOrigen, puertoOrigen, fechaInicioTrayecto, muelleDestino, puertoDestino, fechaFinTrayecto);
		assertEquals(tt.getFechaFinTrayecto(), fechaFinTrayecto);
	}
}